import './App.css';
import React, { useReducer } from 'react'
import { BrowserRouter, Routes, Route } from "react-router-dom"

import Header from "./container/Header"
import Leaderboard from "./container/Leaderboard"
import Game from "./components/Game"
import About from "./components/About"

import Polling from './flux/polling';
import User from './flux/user';
import useLeaderboardApi from './api/leaderboard';
import useUserApi from './api/user';

function App() {
  const pollingFlux = useReducer(Polling.reducer, Polling.initialState);
  const userFlux = useReducer(User.reducer, User.initialState);
  
  const leaderboardApi = useLeaderboardApi(pollingFlux);
  const userApi = useUserApi(userFlux);
  
  const leaderboard = leaderboardApi.get();
  const user = userApi.get();

  return (
    <div className="App" >
      <BrowserRouter>
        <Header pollingFlux={pollingFlux} />
        <Routes>
          {/* https://stackoverflow.com/questions/40541994/multiple-path-names-for-a-same-component-in-react-router */}
          <Route path="/game" element={<Game />} />
          <Route path="/game/new" element={<Game />} />
          <Route path="/game/proposal" element={<Game />} />
          <Route path="/game/active" element={<Game />} />
          <Route path="/game/archive" element={<Game />} />
          <Route path="/leaderboard" element={<Leaderboard leaderboard={leaderboard} user={user} />} />
          <Route path="/about" element={<About />} />
        </Routes>
      </BrowserRouter>
    </div>
  )
}

export default App;
