import { useState, useCallback, useEffect, } from "react"

/*
  - uri: string
  - mode:
    - null  - default, return cashed value while polling fresh one from server)
    - interval_sec
    - interval_stop
*/

export default function usePolling(url, mode) {
    const [cache, setCache] = useState(null);
    const [isFetching, setFetching] = useState(false);
    const [delayID, setDelayID] = useState(null);

    const fetchData = useCallback(() => {
        setDelayID(null);
        setFetching(true);

        fetch(url)
            .then((response) => response.json())
            .then((freshData) => {
                setCache(freshData);
                setFetching(false);
            })
            .catch((err) => {
                console.warn(err.message);
                setFetching(false);
            })
    }, [url])

    useEffect(() => {
        if (cache === null && isFetching === false) {
            fetchData();
        }

        if (mode?.interval_sec && delayID === null) {
            const timeoutID = setTimeout(fetchData, mode.interval_sec * 1000)
            setDelayID(timeoutID)
            console.log("Fetch '" + url + "' scheduled in " + mode.interval_sec + " sec")
        }
        else if (mode?.interval_stop) {
            clearTimeout(delayID);  // cancel already scheduled fetch
            setDelayID(null);       
        }

    }, [url, mode, isFetching, cache, fetchData, delayID]);

    return [
        cache, // API response
        isFetching  // true / false
    ]
}
